@@ -41,8 +41,8 @@ class DataClassHelper:
         self.verify_context_key(key)
         msg = f'Missing context: {key}'
 
-        if not interactive:
-            raise ValueError(msg)
+        # if not io_util.interactive:
+        #     raise ValueError(msg)
 
         print(msg)
         value = input(f'--> set {key} ')
